        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
}
