        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,1,2,4,6,9,11,12,13,14,15,17,19,22,23,24,27,28,29,31,32,33,34,35,37,38,39,40,41,43,47,48,49,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260613 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>3,5,7,8,10,16,18,20,21,25,26,30,36,42,44,45,46';}
}
